@@ -1,6 +1,7 @@
 #ifndef LIBFILEZILLA_LOCAL_FILESYS_HEADER
 #define LIBFILEZILLA_LOCAL_FILESYS_HEADER
 
+#include "fsresult.hpp"
 #include "libfilezilla.hpp"
 #include "time.hpp"
 
@@ -15,36 +16,6 @@
  */
 namespace fz {
 
-/**
- * \brief Small class to return filesystem errors
- */
-class FZ_PUBLIC_SYMBOL result final
-{
-public:
-	enum error {
-		ok,
-
-		/// Permission denied
-		noperm,
-
-		/// Requested file does not exist or is not a file
-		nofile,
-
-		/// Requested dir does not exist or is not a dir
-		nodir,
-
-		/// Out of disk space
-		nospace,
-
-		/// Some other error
-		other
-	};
-
-	explicit operator bool() const { return error_ == 0; }
-
-	error error_{};
-};
-
 /**
  * \brief This class can be used to enumerate the contents of local directories and to query
  * the metadata of files.
@@ -60,6 +31,9 @@ public:
 	local_filesys(local_filesys const&) = delete;
 	local_filesys& operator=(local_filesys const&) = delete;
 
+	local_filesys(local_filesys &&);
+	local_filesys& operator=(local_filesys &&);
+
 	/// Types of files. While 'everything is a file', a filename can refer to a file proper, a directory or a symbolic link.
 	enum type {
 		unknown = -1,
@@ -103,7 +77,23 @@ public:
 	/// \brief Begins enumerating a directory.
 	///
 	/// \param dirs_only If true, only directories are enumerated.
-	result begin_find_files(native_string path, bool dirs_only = false);
+	result begin_find_files(native_string path, bool dirs_only = false, bool query_symlink_targets = true);
+
+#if FZ_WINDOWS
+	/**
+	 * \brief Begin enumerating a directory represented by a HANDLE
+	 *
+	 * Takes ownership of the HANDLE.
+	 */
+	result begin_find_files(HANDLE dir, bool dirs_only = false, bool query_symlink_targets = true);
+#else
+	/**
+	 * \brief Begin enumerating a directory represented by a file descriptor.
+	 *
+	 * Takes ownership of the descriptor.
+	 */
+	result begin_find_files(int fd, bool dirs_only = false, bool query_symlink_targets = true);
+#endif
 
 	/// Gets the next file in the directory. Call until it returns false.
 	bool get_next_file(native_string& name);
@@ -111,11 +101,11 @@ public:
 	/**
 	 * \brief Gets the next file in the directory. Call until it returns false.
 	 *
-	 * Stores the metadata in any non-null arguments. Follows symbolic links.
+	 * Stores the metadata in any non-null arguments. Follows symbolic links iff
+	 * begin_find_files was called with query_symlink_targets set to true.
 	 *
 	 * \param is_link will be set to true iff file is a symbolic link.
-	 * \param t will receive the type of file, after following any symbolic links. Cannot return \c type::link.
-	 *
+	 * \param t will receive the type of file. If query_symlink_targets was set it cannot return \c type::link.
 	 */
 	bool get_next_file(native_string& name, bool &is_link, type & t, int64_t* size, datetime* modification_time, int* mode);
 
@@ -129,18 +119,18 @@ public:
 	static native_string get_link_target(native_string const& path);
 
 private:
-
 #ifdef FZ_WINDOWS
-	WIN32_FIND_DATA m_find_data{};
-	HANDLE m_hFind{INVALID_HANDLE_VALUE};
-	native_string m_find_path;
-	bool has_next_{};
+	bool FZ_PRIVATE_SYMBOL check_buffer();
+	std::vector<unsigned char> buffer_;
+	unsigned char* cur_{};
+	HANDLE dir_{INVALID_HANDLE_VALUE};
 #else
 	DIR* dir_{};
 #endif
 
 	// State for directory enumeration
 	bool dirs_only_{};
+	bool query_symlink_targets_{true};
 };
 
 enum class mkdir_permissions
@@ -175,6 +165,12 @@ enum class mkdir_permissions
  */
 result FZ_PUBLIC_SYMBOL mkdir(native_string const& absolute_path, bool recurse, mkdir_permissions permissions = mkdir_permissions::normal, native_string * last_created = nullptr);
 
+/** \brief Removes sempty directory
+ *
+ * For recursive remove, see \ref fz::recursive_remove
+ */
+result FZ_PUBLIC_SYMBOL remove_dir(native_string const& absolute_path);
+
 /**
  * \brief Rename/move the passed file or directory
  *
