@@ -61,7 +61,7 @@ public:
 	};
 
 	/// A default-constructed timestamp is \ref empty()
-	datetime() = default;
+	datetime() noexcept = default;
 
 	datetime(zone z, int year, int month, int day, int hour = -1, int minute = -1, int second = -1, int millisecond = -1);
 
@@ -110,6 +110,7 @@ public:
 	bool operator<(datetime const& op) const;
 	bool operator<=(datetime const& op) const;
 	bool operator>(datetime const& op) const { return op < *this; }
+	bool operator>=(datetime const& op) const { return op <= *this; }
 	/// \}
 
 	/**
@@ -281,11 +282,13 @@ private:
  * have the time unit as part of the function name.
  *
  * In contract to \ref datetime, \c duration does not track accuracy.
+ * 
+ * \note Arithmetic operations on duration do not check for integer over/underflow
  */
 class FZ_PUBLIC_SYMBOL duration final
 {
 public:
-	duration() = default;
+	duration() noexcept = default;
 
 	/** \name Getters
 	 * All getters return the total time of the duration, rounded down to the requested granularity.
@@ -325,6 +328,11 @@ public:
 		return *this;
 	}
 
+	duration& operator/=(int64_t op) {
+		ms_ /= op;
+		return *this;
+	}
+
 	duration operator-() const {
 		return duration(-ms_);
 	}
@@ -338,6 +346,10 @@ public:
 		return *this;
 	}
 
+	duration absolute() const {
+		return (ms_ < 0) ? duration(-ms_) : *this;
+	}
+
 	bool operator<(duration const& op) const { return ms_ < op.ms_; }
 	bool operator<=(duration const& op) const { return ms_ <= op.ms_; }
 	bool operator>(duration const& op) const { return ms_ > op.ms_; }
@@ -345,6 +357,7 @@ public:
 
 	friend duration FZ_PUBLIC_SYMBOL operator-(duration const& a, duration const& b);
 	friend duration FZ_PUBLIC_SYMBOL operator+(duration const& a, duration const& b);
+	friend duration FZ_PUBLIC_SYMBOL operator/(duration const& a, int64_t b);
 private:
 	explicit FZ_PRIVATE_SYMBOL duration(int64_t ms) : ms_(ms) {}
 
@@ -361,6 +374,11 @@ inline duration operator+(duration const& a, duration const& b)
 	return duration(a) += b;
 }
 
+inline duration operator/(duration const& a, int64_t b)
+{
+	return duration(a) /= b;
+}
+
 /** \relates datetime
  * \relatesalso duration
  * \brief Gets the difference between two timestamps as \ref duration
